@@ -1,5 +1,5 @@
 # mailfe.pl: main routine for dcbib-mailfe(1).
-# $Id: mailfe.pl,v 1.3 2000/09/06 01:38:05 takepiro Exp $
+# $Id: mailfe.pl,v 1.2 1999/05/18 12:47:51 toyoda Exp $
 # Copyright (c) TOYODA Eizi, 1998.  All rights reserved.
 # see COPYING.TXT for terms of license.
 
@@ -13,23 +13,23 @@ while ($_ = shift) {
 }
 
 	&emlOpenFile($CONFIGFILE);
-	%CONFIG = &emlReadHeader();
+	%CONFIG = &emlRead;
 
 	&emlSetFile("STDIN");
-	%MAILHEADER = &emlReadHeader();
+	%MAILHEADER = &emlRead();
 
-	%HEADER = &emlReadHeader();
+	%HEADER = &emlRead();
 
-	unless ($HEADER{"from"}) {
-		$HEADER{"from"} = $MAILHEADER{"sender"}
-		|| $MAILHEADER{"from"}
-		|| $MAILHEADER{"unixfrom"};
+	unless ($HEADER{"from:"}) {
+		$HEADER{"from:"} = $MAILHEADER{"sender:"}
+		|| $MAILHEADER{"from:"}
+		|| $MAILHEADER{"unixfrom:"};
 	}
 
 	## quick hack:  need lock and HAITA
 	$outfnam = "/tmp/dcbib-mailfe";
 	&creat($outfnam);
-	&emlWriteHeader($outfnam, %HEADER);
+	&emlWrite($outfnam, %HEADER);
 	print $outfnam "\n";
 	while (<STDIN>) {
 		print $outfnam $_;
